#       enable_builtin.bash
#
#       This file is part of zenpakt

#       Copyright 2011 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       Zenpakt is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

$DOC
load
====

Synopsis
--------

load builtin [from shared_object]

Description
-----------

load a builtin from shared_object if given or from the value set in variable
ZENPAKT_LOAD_DEFAULT_SO (which should probably be defined at configuration time
and should be readonly). If the shared_object is given then the shared_object is
file is searched for in all the directories in the indexed array
ZENPAKT_LOAD_OBJSPATH and if one is found the builtin is attempted to be loaded
using the file.

The return status of enable if the file is found or else 1

$ENDDOC

$$
load() {
  if (($# == 3)) && [[ $2 = from ]]; then
      local path
      for path in "${ZENPAKT_LOAD_OBJSPATH[@]}" ; do
        if [[ -f $path/$3 ]] ; then
          enable -f "$ZENPAKT_LOAD_OBJSPATH/$3" "$1"
          return
        fi
      done

  elif (($# == 1)); then
    enable -f "$ZENPAKT_LOAD_DEFAULT_SO" "$1"
    return
  fi
  return 1
}

enable_builtin() {
  debug_msg_log "***enable_builtin is deprecated use load***"
  load "$@"
}
